---
Summary: Support Python 3.10
Status: Done
---

# Description

Because of reliance on the tomllib library, only versions of Python >= 3.11 are
supported. Lots of people are still on Python 3.10.

Goal of this card is:

-   use a third party toml library for toml _only_ when pre 3.11 versions of Python are used
-   maintain existing functionality
-   make any other changes where 3.11 specific functionality is used.

The expectation is that 3.10 will be deprecated in time.
